package com.kym.service.admin;

import com.github.yulichang.base.MPJBaseService;
import com.kym.common.R;
import com.kym.entity.admin.AdminUser;
import com.kym.entity.admin.queryParams.CommonQueryParam;
import com.kym.entity.admin.vo.AdminUserVo;
import com.kym.entity.common.PageBean;

import java.util.List;

/**
 * <p>
 * 用户表 服务类
 * </p>
 *
 * @author skyline
 * @since 2023-07-11
 */
public interface AdminUserService extends MPJBaseService<AdminUser> {

    R login(String mobilePhone, String password);

    void logout(Long id);


    Object profile();

    List<AdminUserVo> listUserPermissions(Long loginId);

    PageBean<AdminUserVo> listAdminUser(CommonQueryParam params);

    String createAdminUser(AdminUserVo adminUserVo);

    Object detail(long id);

    void updateRole(long userId, List<Long> roleIdList);

    void updateAdminUser(AdminUserVo adminUserVo);

    PageBean<?> listUser(CommonQueryParam params);

    Object wxLogin(AdminUser user);

    Object loginByOpenId(AdminUser user);
}
